@@ -2,10 +2,10 @@
 # Multiple input/output formats : JSON , XML , YAML, PERL , HUMAN
 #
 # George Bouras , george.mpouras@yandex.com
-# Joan Ntzougani, gravitalsun@hotmail.com
+# Joan Ntzougani, ✞
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.4';
+our	$VERSION = '4.3.5';
 use	strict;
 use	warnings;
 use Encode;
@@ -128,12 +128,6 @@ delete $plg->config->{'Authentication methods'};
 		}
 	}
 
-print "\nApplication             : $app->{name}\n";
-print "Version                 :\n";
-print "  - Application         : ",(exists $app->{config}->{version} ? $app->{config}->{version} : '1.0.0')."\n";
-print "  - WebService          : $Dancer2::Plugin::WebService::VERSION\n";
-print "  - Dancer2             : $Dancer2::VERSION\n";
-print "  - Perl                : $^V\n";
 print 'Run as user             : ', (getpwuid($>))[0]    ,"\n";
 print 'Start time              : ', scalar localtime $^T ,"\n";
 print "Module auth dir scripts : $module_dir\n";
@@ -142,7 +136,9 @@ print "Authorization method    : ", $plg->auth_method ,"\n";
 print "Session directory       : ", $plg->dir_session ,"\n";
 print "Session idle timeout    : ", $plg->Session_timeout ," sec\n";
 print "Main PID                : $$\n";
-
+print "version WebService      : $VERSION\n";
+print "version Dancer2         : $Dancer2::VERSION\n";
+print "version Perl            : $^V\n";
 
 
 # Restore the valid sessions, and delete the expired
@@ -772,7 +768,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.4
+version 4.3.5
 
 =head1 SYNOPSIS
 
@@ -1076,7 +1072,6 @@ Please read the AUTHENTICATION_SCRIPTS for the details
 
 A sample I<config.yml> is the following. 
 
-  version                 : 3.0.0
   environment             : development
   plugins                 :
     WebService            :
